﻿using System;
using System.Data.Entity;
using System.Linq;
using MVCBlog.Core.Entities;

namespace MVCBlog.Core.Database
{
    /// <summary>
    /// Database Context based on EntityFramework (CodeFirst).
    /// </summary>
    internal class DatabaseContext : DbContext
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="DatabaseContext"/> class.
        /// </summary>
        /// <param name="connectionString">The connection string.</param>
        public DatabaseContext(string connectionString)
            : base(connectionString)
        {
        }

        /// <summary>
        /// Gets or sets the <see cref="BlogEntry">BlogEntries</see>.
        /// </summary>
        public DbSet<BlogEntry> BlogEntries { get; set; }

        /// <summary>
        /// Gets or sets the <see cref="BlogEntryComment">BlogEntryComments</see>.
        /// </summary>
        public DbSet<BlogEntryComment> BlogEntryComments { get; set; }

        /// <summary>
        /// Gets or sets the <see cref="BlogEntryFile">BlogEntryFiles</see>.
        /// </summary>
        public DbSet<BlogEntryFile> BlogEntryFiles { get; set; }

        /// <summary>
        /// Gets or sets the <see cref="Image">Images</see>.
        /// </summary>
        public DbSet<Image> Images { get; set; }

        /// <summary>
        /// Gets or sets the <see cref="Tag">Tags</see>.
        /// </summary>
        public DbSet<Tag> Tags { get; set; }

        /// <summary>
        /// Saves all changes made in this context to the underlying database.
        /// </summary>
        /// <returns>
        /// The number of objects written to the underlying database.
        /// </returns>
        /// <exception cref="T:System.InvalidOperationException">Thrown if the context has been disposed.</exception>
        public override int SaveChanges()
        {
            // Set modifiacation date if an entity has been modified
            foreach (var entity in this.ChangeTracker.Entries<EntityBase>().Where(e => e.State == System.Data.EntityState.Modified))
            {
                entity.Entity.Modified = DateTime.Now;
            }

            return base.SaveChanges();
        }
    }
}
