﻿using System;
using System.Data.Entity;
using MVCBlog.Core.Entities;
using MVCBlog.Core.Repository;

namespace MVCBlog.Core.Database
{
    /// <summary>
    /// Inplementation of <see cref="IUnitOfWork"/> using Entity Framework.
    /// </summary>
    internal class EFUnitOfWork : IUnitOfWork, IDisposable
    {
        /// <summary>
        /// The context.
        /// </summary>
        private DbContext context;

        /// <summary>
        /// Initializes a new instance of the <see cref="EFUnitOfWork"/> class.
        /// </summary>
        /// <param name="context">The context.</param>
        public EFUnitOfWork(DbContext context)
        {
            this.context = context;

            this.BlogEntries = new EFRepository<BlogEntry>(context);
            this.BlogEntryComments = new EFRepository<BlogEntryComment>(context);
            this.BlogEntryFiles = new EFRepository<BlogEntryFile>(context);
            this.Images = new EFRepository<Image>(context);
            this.Tags = new EFRepository<Tag>(context);
        }

        /// <summary>
        /// Gets the <see cref="BlogEntry">BlogEntries</see>.
        /// </summary>
        public IRepository<BlogEntry> BlogEntries { get; private set; }

        /// <summary>
        /// Gets the <see cref="BlogEntryComment">BlogEntryComments</see>.
        /// </summary>
        public IRepository<BlogEntryComment> BlogEntryComments { get; private set; }

        /// <summary>
        /// Gets the <see cref="BlogEntryFile">BlogEntryFiles</see>.
        /// </summary>
        public IRepository<BlogEntryFile> BlogEntryFiles { get; private set; }

        /// <summary>
        /// Gets the <see cref="Image">Images</see>.
        /// </summary>
        public IRepository<Image> Images { get; private set; }

        /// <summary>
        /// Gets the <see cref="Tag">Tags</see>.
        /// </summary>
        public IRepository<Tag> Tags { get; private set; }

        /// <summary>
        /// Commits the applied changes.
        /// </summary>
        /// <returns>The number of objects written to the underlying database.</returns>
        public int SaveChanges()
        {
            return this.context.SaveChanges();
        }

        /// <summary>
        /// Performs application-defined tasks associated with freeing, releasing, or resetting unmanaged resources.
        /// </summary>
        public void Dispose()
        {
            this.context.Dispose();

            GC.SuppressFinalize(this);
        }
    }
}
