﻿using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.Text.RegularExpressions;
using System.Web.Mvc;

namespace MVCBlog.Core.Entities
{
    /// <summary>
    /// Represents a BlogEntry.
    /// </summary>
    public class BlogEntry : EntityBase
    {
        /// <summary>
        /// The header.
        /// </summary>
        private string header;

        /// <summary>
        /// Gets or sets the header.
        /// </summary>
        [StringLength(150)]
        [Required(ErrorMessage = "*")]
        public string Header
        {
            get
            {
                return this.header;
            }

            set
            {
                this.header = value;
                this.HeaderUrl = Regex.Replace(
                    value.ToLowerInvariant().Replace(" - ", "-").Replace(" ", "-"),
                    "[^\\w^-]",
                    string.Empty);
            }
        }

        /// <summary>
        /// Gets or sets the header URL.
        /// </summary>
        [StringLength(160)]
        [Required(ErrorMessage = "*")]
        public string HeaderUrl { get; set; }

        /// <summary>
        /// Gets or sets the author.
        /// </summary>
        [StringLength(100)]
        public string Author { get; set; }

        /// <summary>
        /// Gets or sets the short content.
        /// </summary>
        [StringLength(1500)]
        [AllowHtml]
        public string ShortContent { get; set; }

        /// <summary>
        /// Gets or sets the content.
        /// </summary>
        [Required(ErrorMessage = "*")]
        [AllowHtml]
        // TODO: SQL CE does not support nvarchar(max). Therefore 'ntext' is used
        // Comment OUT the following line if you are NOT using SQL CE!
        [Column(TypeName = "ntext")] // Otherwise nvarchar(4000) is used by default
        public string Content { get; set; }

        /// <summary>
        /// Gets or sets a value indicating whether this <see cref="BlogEntry"/> is visible.
        /// </summary>
        public bool Visible { get; set; }

        /// <summary>
        /// Gets or sets the tags.
        /// </summary>
        public virtual ICollection<Tag> Tags { get; set; }

        /// <summary>
        /// Gets or sets the blog entry comments.
        /// </summary>
        public virtual ICollection<BlogEntryComment> BlogEntryComments { get; set; }

        /// <summary>
        /// Gets or sets the blog entry files.
        /// </summary>
        public virtual ICollection<BlogEntryFile> BlogEntryFiles { get; set; }

        /// <summary>
        /// Gets the URL / permalink of the <see cref="BlogEntry"/>.
        /// </summary>
        [NotMapped]
        public string Url
        {
            get
            {
                return this.Created.Year + "/" + this.Created.Month + "/" + this.Created.Day + "/" + this.HeaderUrl;
            }
        }
    }
}
