﻿using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.Web.Mvc;
using MVCBlog.Core.Resources;
using Palmmedia.Common.Linq;

namespace MVCBlog.Core.Entities
{
    /// <summary>
    /// Represents a BlogEntryComment.
    /// </summary>
    public class BlogEntryComment : EntityBase, IValidatableObject
    {
        /// <summary>
        /// Gets or sets the name.
        /// </summary>
        [StringLength(50)]
        public string Name { get; set; }

        /// <summary>
        /// Gets or sets the comment.
        /// </summary>
        [StringLength(2500)]
        [Required(ErrorMessageResourceName = "Comment", ErrorMessageResourceType = typeof(Validation))]
        [AllowHtml]
        public string Comment { get; set; }

        /// <summary>
        /// Gets or sets the email.
        /// </summary>
        [RegularExpression(@"\w+([-+.']\w+)*@\w+([-.]\w+)*\.\w+([-.]\w+)*", ErrorMessageResourceName = "Email", ErrorMessageResourceType = typeof(Validation))]
        [StringLength(50)]
        public string Email { get; set; }

        /// <summary>
        /// Gets or sets the homepage.
        /// </summary>
        [RegularExpression(@"http(s)?://([\w-]+\.)+[\w-]+(/[\w- ./?%&=]*)?", ErrorMessageResourceName = "Homepage", ErrorMessageResourceType = typeof(Validation))]
        [StringLength(100)]
        public string Homepage { get; set; }

        /// <summary>
        /// Gets or sets a value indicating whether [admin post].
        /// </summary>
        public bool AdminPost { get; set; }

        /// <summary>
        /// Gets or sets a value indicating whether this <see cref="BlogEntryComment"/> is visible.
        /// </summary>
        public bool Visible { get; set; }

        /// <summary>
        /// Gets or sets a value indicating whether this <see cref="BlogEntryComment"/> is pingback.
        /// </summary>
        public bool Pingback { get; set; }

        /// <summary>
        /// Gets or sets the blog entry id.
        /// </summary>
        public Guid BlogEntryId { get; set; }

        /// <summary>
        /// Gets or sets the blog entry.
        /// </summary>
        public virtual BlogEntry BlogEntry { get; set; }

        /// <summary>
        /// Determines, whether the given object is valid.
        /// </summary>
        /// <param name="validationContext">The validation context.</param>
        /// <returns>
        /// A list of information of failed validation.
        /// </returns>
        public IEnumerable<ValidationResult> Validate(ValidationContext validationContext)
        {
            if (!this.Pingback && string.IsNullOrWhiteSpace(this.Name))
            {
                yield return new ValidationResult(Resources.Validation.Name, new[] { this.GetPropertyName(b => b.Name) });
            }
        }
    }
}
