﻿using MVCBlog.Core.Entities;

namespace MVCBlog.Core.Repository
{
    /// <summary>
    /// Interface for custom unit of work implementations.
    /// </summary>
    public interface IUnitOfWork
    {
        /// <summary>
        /// Gets the <see cref="BlogEntry">BlogEntries</see>.
        /// </summary>
        IRepository<BlogEntry> BlogEntries { get; }

        /// <summary>
        /// Gets the <see cref="BlogEntryComment">BlogEntryComments</see>.
        /// </summary>
        IRepository<BlogEntryComment> BlogEntryComments { get; }

        /// <summary>
        /// Gets the <see cref="BlogEntryFile">BlogEntryFiles</see>.
        /// </summary>
        IRepository<BlogEntryFile> BlogEntryFiles { get; }

        /// <summary>
        /// Gets the <see cref="Image">Images</see>.
        /// </summary>
        IRepository<Image> Images { get; }

        /// <summary>
        /// Gets the <see cref="Tag">Tags</see>.
        /// </summary>
        IRepository<Tag> Tags { get; }

        /// <summary>
        /// Commits the applied changes.
        /// </summary>
        /// <returns>The number of objects written to the underlying database.</returns>
        int SaveChanges();
    }
}
