﻿using System;
using System.Collections.Generic;
using Palmmedia.Common.Linq;

namespace MVCBlog.Core.Service
{
    /// <summary>
    /// Generic interface for accessing entities.
    /// </summary>
    /// <typeparam name="T">Class that derives from <see cref="MVCBlog.Core.Entities.EntityBase"/>.</typeparam>
    public interface IGenericEntityService<T> where T : MVCBlog.Core.Entities.EntityBase
    {
        /// <summary>
        /// Adds the given element to the <see cref="MVCBlog.Core.Repository.IRepository{T}"/>.
        /// </summary>
        /// <param name="entity">The element to add.</param>
        void Add(T entity);

        /// <summary>
        /// Deletes the given element from the <see cref="MVCBlog.Core.Repository.IRepository{T}"/>.
        /// </summary>
        /// <param name="entity">The element to delete.</param>
        void Delete(T entity);

        /// <summary>
        /// Updates the given element in the <see cref="MVCBlog.Core.Repository.IRepository{T}"/>.
        /// </summary>
        /// <param name="entity">The element to update.</param>
        void Update(T entity);

        /// <summary>
        /// Returns the <see cref="MVCBlog.Core.Entities.EntityBase"/> with the given id.
        /// </summary>
        /// <param name="id">The id.</param>
        /// <returns>The <see cref="MVCBlog.Core.Entities.EntityBase"/> with the given id.</returns>
        T GetById(Guid id);

        /// <summary>
        /// Returns an <see cref="IEnumerable{T}"/> from the <see cref="MVCBlog.Core.Repository.IRepository{T}"/>.
        /// </summary>
        /// <returns>
        /// The <see cref="IEnumerable{T}"/> of all elements.
        /// </returns>
        IEnumerable<T> GetAll();

        /// <summary>
        /// Returns an <see cref="IEnumerable{T}"/> from the <see cref="MVCBlog.Core.Repository.IRepository{T}"/>.
        /// </summary>
        /// <param name="paging">The <see cref="Paging"/>.</param>
        /// <returns>
        /// The <see cref="PagedResult{T}"/> of all elements.
        /// </returns>
        PagedResult<T> GetAll(Paging paging);
    }
}
