﻿using System;
using System.Collections.Generic;
using System.Data.Entity;
using System.Linq;
using MVCBlog.Core.Entities;
using MVCBlog.Core.Repository;

namespace MVCBlog.Core.Service
{
    /// <summary>
    /// Access to <see cref="BlogEntryFile">BlogEntryFiles</see>.
    /// </summary>
    public class BlogEntryFileService : GenericEntityService<BlogEntryFile>, IBlogEntryFileService
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="BlogEntryFileService"/> class.
        /// </summary>
        /// <param name="unitOfWork">The <see cref="IUnitOfWork"/>.</param>
        public BlogEntryFileService(IUnitOfWork unitOfWork)
            : base(unitOfWork.BlogEntryFiles, unitOfWork)
        {
        }

        /// <summary>
        /// Returns an <see cref="IEnumerable{T}"/> from the <see cref="MVCBlog.Core.Repository.IRepository{T}"/>.
        /// </summary>
        /// <returns>
        /// The <see cref="IEnumerable{T}"/> of all elements.
        /// </returns>
        public override IEnumerable<BlogEntryFile> GetAll()
        {
            var files = this.Repository.GetQuery()
                .Include(b => b.BlogEntry)
                .OrderByDescending(f => f.BlogEntry.Created);

            return files;
        }

        /// <summary>
        /// Deletes the given element from the <see cref="MVCBlog.Core.Repository.IRepository{T}"/>.
        /// </summary>
        /// <param name="entity">The element to delete.</param>
        public override void Delete(BlogEntryFile entity)
        {
            if (entity == null)
            {
                throw new ArgumentNullException("entity");
            }

            entity.DeleteData();
            base.Delete(entity);
        }
    }
}
