﻿using System.Configuration;
using System.Web.Mvc;
using System.Web.Routing;
using log4net;

namespace MVCBlog.Website
{
    /// <summary>
    /// Defines the methods, properties, and events in this ASP.NET application.
    /// </summary>
    public class MvcApplication : System.Web.HttpApplication
    {
        /// <summary>
        /// Logger instance.
        /// </summary>
        private static readonly ILog logger = LogManager.GetLogger(typeof(MvcApplication));

        /// <summary>
        /// Registers the global filters.
        /// </summary>
        /// <param name="filters">The filters.</param>
        public static void RegisterGlobalFilters(GlobalFilterCollection filters)
        {
            filters.Add(new Palmmedia.Common.Net.Mvc.HandleErrorAttribute());
            filters.Add(new Palmmedia.Common.Net.Mvc.Localization.LocalizeAttribute());
            filters.Add(new Palmmedia.Common.Net.PingBack.PingbackAttribute(ConfigurationManager.AppSettings["PingbackHandler"]));
        }

        /// <summary>
        /// Registers the routes.
        /// </summary>
        /// <param name="routes">The routes.</param>
        public static void RegisterRoutes(RouteCollection routes)
        {
            routes.IgnoreRoute("{resource}.axd/{*pathInfo}");
            routes.IgnoreRoute("{*favicon}", new { favicon = @"(.*/)?favicon.ico(/.*)?" });

            // Short URL for '404'
            routes.MapRoute(
                "Short_404",
                "404",
                new { controller = MVC.Error.Name, action = MVC.Error.ActionNames.NotFound });

            // Short URL for 'Logout'
            routes.MapRoute(
                "Short_Logout",
                "Logout",
                new { controller = MVC.Login.Name, action = MVC.Login.ActionNames.Logout });

            routes.MapRoute(
                Routes.BLOGENTRY,
                MVC.Blog.Name + "/{year}/{month}/{day}/{id}",
                new { controller = MVC.Blog.Name, action = MVC.Blog.ActionNames.Entry },
                new { year = "\\d{4}", month = "\\d{1,2}", day = "\\d{1,2}", id = ".+" });

            routes.MapRoute(
            Routes.TAGPAGING,
               MVC.Blog.Name + "/Tag/{tag}/Page/{page}",
               new { controller = MVC.Blog.Name, action = MVC.Blog.ActionNames.Index },
               new { tag = ".+", page = "\\d+" });

            routes.MapRoute(
               Routes.TAG,
               MVC.Blog.Name + "/Tag/{tag}",
               new { controller = MVC.Blog.Name, action = MVC.Blog.ActionNames.Index },
               new { tag = ".+" });

            routes.MapRoute(
               Routes.BLOGPAGING,
               MVC.Blog.Name + "/Page/{page}",
               new { controller = MVC.Blog.Name, action = MVC.Blog.ActionNames.Index },
               new { page = "\\d+" });

            routes.MapRoute(
                Routes.DEFAULT,
                "{controller}/{action}/{id}",
                new { controller = MVC.Blog.Name, action = MVC.Blog.ActionNames.Index, id = UrlParameter.Optional });
        }

        /// <summary>
        /// Executed when the ASP.NET application starts.
        /// </summary>
        protected void Application_Start()
        {
            // Init logger
            log4net.Config.XmlConfigurator.Configure();

            Bootstrapper.Initialise();

            AreaRegistration.RegisterAllAreas();

            ViewEngines.Engines.Clear();
            ViewEngines.Engines.Add(new Palmmedia.Common.Net.Mvc.Localization.LocalizationRazorViewEngine());

            RegisterGlobalFilters(GlobalFilters.Filters);
            RegisterRoutes(RouteTable.Routes);
        }
    }
}